@@ -1,34 +1,46 @@
 #' Model-specific variable importance
 #'
 #' Compute model-specific variable importance scores for the predictors in a
-#' model.
+#' fitted model.
 #'
-#' @param object A fitted model object (e.g., a \code{"randomForest"} object).
+#' @param object A fitted model object (e.g., a
+#' [randomForest][randomForest::randomForest] object). See the details section
+#' below to see how variable importance is computed for supported model types.
 #'
 #' @param type Character string specifying the type of variable importance to
-#' return (only used for some models). See details for which methods this
-#' argument applies to.
+#' return (only used for some models). See the details section below for which
+#' methods this argument applies to.
 #'
 #' @param lambda Numeric value for the penalty parameter of a
-#' \code{\link[glmnet]{glmnet}} model (this is equivalent to the \code{s}
-#' argument in \code{\link[glmnet:predict.glmnet]{coef.glmnet}}). See the section on
-#' \code{\link[glmnet]{glmnet}} in the details below.
+#' [glmnet][glmnet::glmnet] model (this is equivalent to the `s`
+#' argument in [coef.glmnet][glmnet::coef.glmnet()]). See the section on
+#' [glmnet][glmnet::glmnet] in the details below.
+#'
+#' @param ncomp An integer for the number of partial least squares components
+#' to be used in the importance calculations. If more components are requested
+#' than were used in the model, all of the model's components are used.
 #'
 #' @param ... Additional optional arguments to be passed on to other methods.
+#' See the details section below for arguments that can be passed to specific
+#' object types.
 #'
-#' @return A tidy data frame (i.e., a \code{"tibble"} object) with two columns:
-#' \code{Variable} and \code{Importance}. For \code{"lm"/"glm"}-like object, an
-#' additional column, called \code{Sign}, is also included which includes the
-#' sign (i.e., POS/NEG) of the original coefficient.
+#' @return A tidy data frame (i.e., a [tibble][tibble::tibble] object) with two
+#' columns:
+#'
+#' * `Variable` - the corresponding feature name;
+#' * `Importance` - the associated importance, computed as the average change in
+#' performance after a random permutation (or permutations, if `nsim > 1`) of
+#' the feature in question.
+#'
+#' For [lm][stats::lm]/[glm][stats::glm]-like objects, the sign (i.e., POS/NEG)
+#' of the original coefficient is also included in a column called `Sign`.
 #'
 #' @details
 #'
 #' Computes model-specific variable importance scores depending on the class of
-#' \code{object}:
+#' `object`:
 #'
-#' \describe{
-#'
-#' \item{\code{\link[C50]{C5.0}}}{Variable importance is measured by determining
+#' * [C5.0][C50::C5.0] - Variable importance is measured by determining
 #' the percentage of training set samples that fall into all the terminal nodes
 #' after the split. For example, the predictor in the first split automatically
 #' has an importance measurement of 100 percent since all samples are affected
@@ -37,10 +49,10 @@
 #' scores may be close to zero. The same strategy is applied to rule-based
 #' models and boosted versions of the model. The underlying function can also
 #' return the number of times each predictor was involved in a split by using
-#' the option \code{metric = "usage"}. See \code{\link[C50]{C5imp}} for
-#' details.}
+#' the option `metric = "usage"`. See [C5imp][C50::C5imp()] for
+#' details.
 #'
-#' \item{\code{\link[Cubist:cubist.default]{cubist}}}{The Cubist output contains variable usage
+#' * [cubist][Cubist::cubist.default] - The Cubist output contains variable usage
 #' statistics. It gives the percentage of times where each variable was used in
 #' a condition and/or a linear model. Note that this output will probably be
 #' inconsistent with the rules shown in the output from summary.cubist. At each
@@ -53,104 +65,98 @@
 #' the Cubist output reflects all the models involved in prediction (as opposed
 #' to the terminal models shown in the output). The variable importance used
 #' here is a linear combination of the usage in the rule conditions and the
-#' model. See \code{\link[Cubist]{summary.cubist}} and
-#' \code{\link[caret:varImp]{varImp.cubist}} for details.}
+#' model. See [summary.cubist][Cubist::summary.cubist()] and
+#' [varImp][caret::varImp()] for details.
 #'
-#' \item{\code{\link[glmnet]{glmnet}}}{Similar to (generalized) linear models,
+#' * [glmnet][glmnet::glmnet] - Similar to (generalized) linear models,
 #' the absolute value of the coefficients are returned for a specific model.
 #' It is important that the features  (and hence, the estimated coefficients) be
 #' standardized prior to fitting the model. You can specify which coefficients
 #' to return by passing the specific value of the penalty parameter via the
-#' \code{lambda} argument (this is equivalent to the \code{s} argument in
-#' \code{\link[glmnet:predict.glmnet]{coef.glmnet}}). By default, \code{lambda = NULL} and the coefficients
+#' `lambda` argument (this is equivalent to the `s` argument in
+#' [coef.glmnet][glmnet::coef.glmnet()]). By default, `lambda = NULL` and the coefficients
 #' corresponding to the final penalty value in the sequence are returned; in
-#' other words, you should ALWAYS SPECIFY \code{lambda}! For \code{"cv.glmnet"}
+#' other words, you should ALWAYS SPECIFY `lambda`! For [cv.glmnet][glmnet::cv.glmnet]
 #' objects, the largest value of lambda such that the error is within one standard
-#' error of the minimum is used by default. For \code{"multnet"} objects, the
+#' error of the minimum is used by default. For a multinomial response, the
 #' coefficients corresponding to the first class are used; that is, the first
-#' component of \code{\link[glmnet:predict.glmnet]{coef.glmnet}}.}
+#' component of [coef.glmnet][glmnet::coef.glmnet()].
 #'
-#' \item{\code{\link[partykit]{cforest}}}{Variable importance is measured in a
-#' way similar to those computed by \code{\link[randomForest]{importance}}.
+#' * [cforest][partykit::cforest] - Variable importance is measured in a
+#' way similar to those computed by [importance][randomForest::importance()].
 #' Besides the standard version, a conditional version is available that
 #' adjusts for correlations between predictor variables. If
-#' \code{conditional = TRUE}, the importance of each variable is computed by
+#' `conditional = TRUE`, the importance of each variable is computed by
 #' permuting within a grid defined by the predictors that are associated (with
-#' 1 - \emph{p}-value greater than threshold) to the variable of interest. The
+#' 1 - *p*-value greater than threshold) to the variable of interest. The
 #' resulting variable importance score is conditional in the sense of beta
 #' coefficients in regression models, but represents the effect of a variable in
 #' both main effects and interactions. See Strobl et al. (2008) for details.
 #' Note, however, that all random forest results are subject to random
 #' variation. Thus, before interpreting the importance ranking, check whether
 #' the same ranking is achieved with a different random seed - or otherwise
-#' increase the number of trees ntree in \code{\link[partykit]{ctree_control}}.
+#' increase the number of trees ntree in [ctree_control][partykit::ctree_control()].
 #' Note that in the presence of missings in the predictor variables the
 #' procedure described in Hapfelmeier et al. (2012) is performed. See
-#' \code{\link[partykit]{varimp}} for details.}
+#' [varimp][partykit::varimp()] for details.
 #'
-#' \item{\code{\link[earth]{earth}}}{The \code{\link[earth]{earth}} package uses
+#' * [earth][earth::earth] - The [earth][earth::earth] package uses
 #' three criteria for estimating the variable importance in a MARS model (see
-#' \code{\link[earth]{evimp}} for details):
-#' \itemize{
+#' [evimp][earth::evimp] for details):
 #'
-#'   \item The \code{nsubsets} criterion (\code{type = "nsubsets"}) counts the
+#'   - The `nsubsets` criterion (`type = "nsubsets"`) counts the
 #'   number of model subsets that include each feature. Variables that are
 #'   included in more subsets are considered more important. This is the
-#'   criterion used by \code{\link[earth]{summary.earth}} to print variable
+#'   criterion used by [summary.earth][earth::summary.earth] to print variable
 #'   importance. By "subsets" we mean the subsets of terms generated by
-#'   \code{earth()}'s backward pass. There is one subset for each model size
+#'   `earth()`'s backward pass. There is one subset for each model size
 #'   (from one to the size of the selected model) and the subset is the best set
 #'   of terms for that model size. (These subsets are specified in the
-#'   \code{$prune.terms} component of \code{earth()}'s return value.) Only
+#'   `$prune.terms` component of `earth()`'s return value.) Only
 #'   subsets that are smaller than or equal in size to the final model are used
 #'   for estimating variable importance. This is the default method used by
-#'   \strong{vip}.
+#'   [vi_model][vip::vi_model].
 #'
-#'   \item The \code{rss} criterion (\code{type = "rss"}) first calculates the
+#'   - The `rss` criterion (`type = "rss"`) first calculates the
 #'   decrease in the RSS for each subset relative to the previous subset during
-#'   \code{earth()}’s backward pass. (For multiple response models, RSS's are
+#'   `earth()`’s backward pass. (For multiple response models, RSS's are
 #'   calculated over all responses.) Then for each variable it sums these
 #'   decreases over all subsets that include the variable. Finally, for ease of
 #'   interpretation the summed decreases are scaled so the largest summed
 #'   decrease is 100. Variables which cause larger net decreases in the RSS are
 #'   considered more important.
 #'
-#'   \item The \code{gcv} criterion (\code{type = "gcv"}) is similar to the
-#'   \code{rss} approach, but uses the GCV statistic instead of the RSS. Note
+#'   - The `gcv` criterion (`type = "gcv"`) is similar to the
+#'   `rss` approach, but uses the GCV statistic instead of the RSS. Note
 #'   that adding a variable can sometimes increase the GCV. (Adding the variable
 #'   has a deleterious effect on the model, as measured in terms of its
 #'   estimated predictive power on unseen data.) If that happens often enough,
 #'   the variable can have a negative total importance, and thus appear less
 #'   important than unused variables.
 #'
-#' }}
+#' * [gbm][gbm::gbm] - Variable importance is computed using one of
+#' two approaches (See [summary.gbm][gbm::summary.gbm] for details):
 #'
-#' \item{\code{\link[gbm]{gbm}}}{Variable importance is computed using one of
-#' two approaches (See \code{\link[gbm]{summary.gbm}} for details):
-#' \itemize{
-#'
-#'   \item The standard approach (\code{type = "relative.influence"}) described
-#'   in Friedman (2001). When \code{distribution = "gaussian"} this returns the
+#'   - The standard approach (`type = "relative.influence"`) described
+#'   in Friedman (2001). When `distribution = "gaussian"` this returns the
 #'   reduction of squared error attributable to each variable. For other loss
 #'   functions this returns the reduction attributable to each variable in sum
 #'   of squared error in predicting the gradient on each iteration. It describes
-#'   the \emph{relative influence} of each variable in reducing the loss
-#'   function. This is the default method used by \strong{vip}.
+#'   the *relative influence* of each variable in reducing the loss
+#'   function. This is the default method used by [vi_model][vip::vi_model].
 #'
-#'   \item An experimental permutation-based approach
-#'   (\code{type = "permutation"}). This method randomly permutes each predictor
+#'   - An experimental permutation-based approach
+#'   (`type = "permutation"`). This method randomly permutes each predictor
 #'   variable at a time and computes the associated reduction in predictive
 #'   performance. This is similar to the variable importance measures Leo
-#'   Breiman uses for random forests, but \strong{gbm} currently computes using
+#'   Breiman uses for random forests, but [gbm][gbm::gbm] currently computes using
 #'   the entire training dataset (not the out-of-bag observations).
 #'
-#' }}
+#' * [H2OModel][h2o::H2OModel] - See [h2o.varimp][h2o::h2o.varimp] or visit
+#' \url{https://docs.h2o.ai/h2o/latest-stable/h2o-docs/variable-importance.html}
+#' for details.
 #'
-#' \item{\code{\link[h2o:H2OModel-class]{H2OModel}}}{See \code{\link[h2o]{h2o.varimp}} or visit
-#' \url{http://docs.h2o.ai/h2o/latest-stable/h2o-docs/variable-importance.html}
-#' for details.}
-#'
-#' \item{\code{\link[nnet]{nnet}}}{Two popular methods for constructing variable
+#' * [nnet][nnet::nnet] - Two popular methods for constructing variable
 #' importance scores with neural networks are the Garson algorithm
 #' (Garson 1991), later modified by Goh (1995), and the Olden algorithm
 #' (Olden et al. 2004). For both algorithms, the basis of these importance
@@ -163,50 +169,57 @@
 #' Gedeon (1997) considers the weights connecting the input features to the
 #' first two hidden layers (for simplicity and speed); but this method can be
 #' slow for large networks.. To implement the Olden and Garson algorithms, use
-#' \code{type = "olden"} and \code{type = "garson"}, respectively. See
-#' \code{\link[NeuralNetTools]{garson}} and \code{\link[NeuralNetTools]{olden}}
-#' for details.}
+#' `type = "olden"` and `type = "garson"`, respectively. See
+#' [garson][NeuralNetTools::garson] and [olden][NeuralNetTools::olden]
+#' for details.
 #'
-#' \item{\code{\link[stats]{lm}}}{In (generalized) linear models, variable
-#' importance is typically based on the absolute value of the corresponding
-#' \emph{t}-statistics. For such models, the sign of the original coefficient
-#' is also returned. By default, \code{type = "stat"} is used; however, if the
-#' inputs have been appropriately standardized then the raw coefficients can be
-#' used with \code{type = "raw"}.}
+#' * [lm][stats::lm]/[glm][stats::glm] - In (generalized) linear models,
+#' variable importance is typically based on the absolute value of the
+#' corresponding *t*-statistics (Bring, 1994). For such models, the sign of the
+#' original coefficient is also returned. By default, `type = "stat"` is used;
+#' however, if the inputs have been appropriately standardized then the raw
+#' coefficients can be used with `type = "raw"`. Note that Bring (1994)
+#' provides motivation for using the absolute value of the associated
+#' *t*-statistics.
 #'
-#' \item{\code{\link[sparklyr]{ml_feature_importances}}}{The Spark ML
-#' library provides standard variable importance for tree-based methods (e.g.,
-#' random forests). See \code{\link[sparklyr]{ml_feature_importances}} for
-#' details.}
+#' * [sparklyr][sparklyr::ml_feature_importances] - The Spark ML
+#' library provides standard variable importance measures for tree-based methods
+#' (e.g., random forests). See
+#' [ml_feature_importances][sparklyr::ml_feature_importances] for details.
 #'
-#' \item{\code{\link[randomForest]{randomForest}}}{Random forests typically
-#' provide two measures of variable importance. The first measure is computed
-#' from permuting out-of-bag (OOB) data: for each tree, the prediction error on
-#' the OOB portion of the data is recorded (error rate for classification and
-#' MSE for regression). Then the same is done after permuting each predictor
-#' variable. The difference between the two are then averaged over all trees in
-#' the forest, and normalized by the standard deviation of the differences. If
-#' the standard deviation of the differences is equal to 0 for a variable,
-#' the division is not done (but the average is almost always equal to 0 in that
-#' case). See \code{\link[randomForest]{importance}} for details, including
-#' additional arguments that can be passed via the \code{...} argument.
+#' * [randomForest][randomForest::randomForest] Random forests typically
+#' provide two measures of variable importance.
 #'
-#' The second measure is the total decrease in node impurities from splitting on
-#' the variable, averaged over all trees. For classification, the node impurity
-#' is measured by the Gini index. For regression, it is measured by residual sum
-#' of squares. See \code{\link[randomForest]{importance}} for details.}
+#'   - The first measure is computed from permuting out-of-bag (OOB) data: for
+#'   each tree, the prediction error on the OOB portion of the data is recorded
+#'   (error rate for classification and MSE for regression). Then the same is
+#'   done after permuting each predictor variable. The difference between the
+#'   two are then averaged over all trees in the forest, and normalized by the
+#'   standard deviation of the differences. If the standard deviation of the
+#'   differences is equal to 0 for a variable, the division is not done (but the
+#'   average is almost always equal to 0 in that case).
 #'
-#' \item{\code{\link[party]{cforest}}}{Same approach described in
-#' \code{\link[partykit]{cforest}} above. See \code{\link[party]{varimp}} and
-#' \code{\link[party:varimp]{varimpAUC}} (if \code{type = "auc"}) for details.}
+#'   - The second measure is the total decrease in node impurities from
+#'   splitting on the variable, averaged over all trees. For classification, the
+#'   node impurity is measured by the Gini index. For regression, it is measured
+#'   by residual sum of squares.
 #'
-#' \item{\code{\link[ranger]{ranger}}}{Variable importance for
-#' \code{\link[ranger]{ranger}} objects is computed in the usual way for random
-#' forests. The approach used depends on the \code{importance} argument provided
-#' in the initial call to \code{\link[ranger]{ranger}}. See
-#' \code{\link[ranger:importance.ranger]{importance}} for details.}
+#'   See [importance][randomForest::importance] for details, including
+#' additional arguments that can be passed via the `...` argument in
+#' [vi_model][vip::vi_model].
 #'
-#' \item{\code{\link[rpart]{rpart}}}{As stated in one of the \strong{rpart}
+#' * [cforest][party::cforest] - Same approach described in
+#' [cforest][partykit::cforest] (from package **partykit**) above. See
+#' [varimp][party::varimp] and [varimpAUC][party::varimpAUC] (if `type = "auc"`)
+#' for details.
+#'
+#' * [ranger][ranger::ranger] - Variable importance for
+#' [ranger][ranger::ranger] objects is computed in the usual way for random
+#' forests. The approach used depends on the `importance` argument provided
+#' in the initial call to [ranger][ranger::ranger]. See
+#' [importance][ranger::importance] for details.
+#'
+#' * [rpart][rpart::rpart] - As stated in one of the [rpart][rpart::rpart]
 #' vignettes. A variable may appear in the tree many times, either as a primary
 #' or a surrogate variable. An overall measure of variable importance is the sum
 #' of the goodness of split measures for each split for which it was the primary
@@ -214,43 +227,77 @@
 #' was a surrogate. Imagine two variables which were essentially duplicates of
 #' each other; if we did not count surrogates, they would split the importance
 #' with neither showing up as strongly as it should. See
-#' \code{\link[rpart]{rpart}} for details.}
+#' [rpart][rpart::rpart] for details.
 #'
-#' \item{\code{\link[caret]{train}}}{Various model-specific and model-agnostic
+#' * [caret][caret::train] - Various model-specific and model-agnostic
 #' approaches that depend on the learning algorithm employed in the original
-#' call to \code{\link[caret]{train}}. See \code{\link[caret]{varImp}} for
-#' details.}
+#' call to [caret][caret::train]. See [varImp][caret::varImp] for details.
 #'
-#' \item{\code{\link[xgboost:xgb.train]{xgboost}}}{For linear models, the variable
+#' * [xgboost][xgboost::xgboost] - For linear models, the variable
 #' importance is the absolute magnitude of the estimated coefficients. For that
 #' reason, in order to obtain a meaningful ranking by importance for a linear
 #' model, the features need to be on the same scale (which you also would want
 #' to do when using either L1 or L2 regularization). Otherwise, the approach
-#' described in Friedman (2001) for \code{\link[gbm]{gbm}}s is used. See
-#' \code{\link[xgboost:xgb.train]{xgb.importance}} for details. For tree models, you can
-#' obtain three different types of variable importance:
-#' \itemize{
+#' described in Friedman (2001) for [gbm][gbm::gbm]s is used. See
+#' [xgb.importance][xgboost::xgb.importance] for details. For tree models, you
+#' can obtain three different types of variable importance:
 #'
-#'   \item Using \code{type = "gain"} (the default) gives the fractional
-#'   contribution of each feature to the model based on the total gain of the
-#'   corresponding feature's splits.
+#'   - Using `type = "gain"` (the default) gives the fractional contribution of
+#'   each feature to the model based on the total gain of the corresponding
+#'   feature's splits.
 #'
-#'   \item Using \code{type = "cover"} gives the number of observations related
-#'   to each feature.
+#'   - Using `type = "cover"` gives the number of observations related to each
+#'   feature.
 #'
-#'   \item Using \code{type = "frequency"} gives the percentages representing
+#'   - Using `type = "frequency"` gives the percentages representing
 #'   the relative number of times each feature has been used throughout each
 #'   tree in the ensemble.
 #'
-#' }}
+#' * [lightgbm][lightgbm::lightgbm] - Same as for [xgboost][xgboost::xgboost]
+#' models, except [lgb.importance][lightgbm::lgb.importance] (which this method
+#' calls internally) has an additional argument, `percentage`, that defaults to
+#' `TRUE`, resulting in the VI scores shown as a relative percentage; pass
+#' `percentage = FALSE` in the call to `vi_model()` to produce VI scores for
+#' [lightgbm][lightgbm::lightgbm] models on the raw scale.
 #'
-#' }
+#' @source
+#' Johan Bring (1994) How to Standardize Regression Coefficients, The American
+#' Statistician, 48:3, 209-213, DOI: 10.1080/00031305.1994.10476059.
 #'
-#' @note Inspired by the \code{\link[caret]{varImp}} function.
+#' @note Inspired by the [caret](https://cran.r-project.org/package=caret)'s
+#' [varImp][caret::varImp] function.
 #'
 #' @rdname vi_model
 #'
 #' @export
+#'
+#' @examples
+#' \dontrun{
+#' # Basic example using imputed titanic data set
+#' t3 <- titanic_mice[[1L]]
+#'
+#' # Fit a simple model
+#' set.seed(1449)  # for reproducibility
+#' bst <- lightgbm::lightgbm(
+#'   data = data.matrix(subset(t3, select = -survived)),
+#'   label = ifelse(t3$survived == "yes", 1, 0),
+#'   params = list("objective" = "binary", "force_row_wise" = TRUE),
+#'   verbose = 0
+#' )
+#'
+#' # Compute VI scores
+#' vi(bst)  # defaults to `method = "model"`
+#' vi_model(bst)  # same as above
+#'
+#' # Same as above (since default is `method = "model"`), but returns a plot
+#' vip(bst, geom = "point")
+#' vi_model(bst, type = "cover")
+#' vi_model(bst, type = "cover", percentage = FALSE)
+#'
+#' # Compare to
+#' lightgbm::lgb.importance(bst)
+#' }
+#'
 vi_model <- function(object, ...) {
   UseMethod("vi_model")
 }
@@ -610,12 +657,105 @@ vi_model.H2ORegressionModel <- function(object, ...) {
 }
 
 
+# Package: lightgbm ------------------------------------------------------------
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.lgb.Booster <- function(object, type = c("gain", "cover", "frequency"),
+                                 ...) {
+
+  # # Check for dependency
+  # if (!requireNamespace("xgboost", quietly = TRUE)) {
+  #   stop("Package \"xgboost\" needed for this function to work. Please ",
+  #        "install it.", call. = FALSE)
+  # }
+
+  # Determine which type of variable importance to compute
+  type <- match.arg(type)
+
+  # Construct model-specific variable importance scores
+  imp <- lightgbm::lgb.importance(model = object, ...)
+  names(imp) <- tolower(names(imp))
+  # if ("weight" %in% names(imp)) {
+  #   type <- "weight"  # gblinear
+  # }
+  vis <- tibble::as_tibble(imp)[, c("feature", type)]
+  tib <- tibble::tibble(
+    "Variable" = vis$feature,
+    "Importance" = vis[[2L]]
+  )
+
+  # Add variable importance type attribute
+  attr(tib, which = "type") <- type
+
+  # Add "vi" class
+  class(tib) <- c("vi", class(tib))
+
+  # Return results
+  tib
+
+}
+
+
+# Package: mixOmics  -----------------------------------------------------------
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.mixo_pls <- function(object, ncomp = NULL, ...) {
+
+  # Check for dependency
+  if (!requireNamespace("mixOmics", quietly = TRUE)) {
+    stop("Bioconductor package \"mixOmics\" needed for this function to work. ",
+         "Please install it.", call. = FALSE)
+  }
+  if (is.null(ncomp)) {
+    ncomp <- object$ncomp
+  } else {
+    if (length(ncomp) != 1) {
+      stop("'ncomp' should be a single integer.")
+    }
+    if (!is.integer(ncomp)) {
+      ncomp <- as.integer(ncomp)
+    }
+  }
+
+  vis <- mixOmics::vip(object)
+  if (ncomp > ncol(vis)) {
+    warning(ncomp, " components were requested but only ", ncol(vis),
+            " are available. Results are for ", ncol(vis), ".")
+    ncomp <- ncol(vis)
+  }
+
+  tib <- tibble::tibble(
+    "Variable" = rownames(vis),
+    "Importance" = vis[,ncomp]
+  )
+
+  # Add variable importance type attribute
+  attr(tib, which = "type") <- "mixOmics"
+
+  # Add "vi" class
+  class(tib) <- c("vi", class(tib))
+
+  # Return results
+  tib
+
+}
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.mixo_spls <- vi_model.mixo_pls
+
+
 # Package: mlr -----------------------------------------------------------------
 
 #' @rdname vi_model
 #'
 #' @export
-vi_model.WrappedModel <- function(object, ...) {  # package: mlr
+vi_model.WrappedModel <- function(object, ...) {
   vi_model(object$learner.model, ...)
 }
 
@@ -625,7 +765,7 @@ vi_model.WrappedModel <- function(object, ...) {  # package: mlr
 #' @rdname vi_model
 #'
 #' @export
-vi_model.Learner <- function(object, ...) {  # package: mlr3
+vi_model.Learner <- function(object, ...) {
   if (is.null(object$model)) {
     stop("No fitted model found. Did you forget to call ",
          deparse(substitute(object)), "$train()?",
@@ -721,16 +861,6 @@ vi_model.nnet <- function(object, type = c("olden", "garson"), ...) {
 }
 
 
-# Package: parsnip -------------------------------------------------------------
-
-#' @rdname vi_model
-#'
-#' @export
-vi_model.model_fit <- function(object, ...) {  # package: parsnip
-  vi_model(object$fit, ...)
-}
-
-
 # Package: party ---------------------------------------------------------------
 
 #' @rdname vi_model
@@ -871,6 +1001,82 @@ vi_model.mvr <- function(object, ...) {
 
 }
 
+# Package: mixOmics  -----------------------------------------------------------
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.mixo_pls <- function(object, ncomp = NULL, ...) {
+
+  # Check for dependency
+  if (!requireNamespace("mixOmics", quietly = TRUE)) {
+    stop("Bioconductor package \"mixOmics\" needed for this function to work. ",
+         "Please install it.", call. = FALSE)
+  }
+  if (is.null(ncomp)) {
+    ncomp <- object$ncomp
+  } else {
+    if (length(ncomp) != 1) {
+      stop("'ncomp' should be a single integer.")
+    }
+    if (!is.integer(ncomp)) {
+      ncomp <- as.integer(ncomp)
+    }
+  }
+
+  vis <- mixOmics::vip(object)
+  if (ncomp > ncol(vis)) {
+    warning(ncomp, " components were requested but only ", ncol(vis),
+            " are available. Results are for ", ncol(vis), ".")
+    ncomp <- ncol(vis)
+  }
+
+  tib <- tibble::tibble(
+    "Variable" = rownames(vis),
+    "Importance" = vis[,ncomp]
+  )
+
+  # Add variable importance type attribute
+  attr(tib, which = "type") <- "mixOmics"
+
+  # Add "vi" class
+  class(tib) <- c("vi", class(tib))
+
+  # Return results
+  tib
+
+}
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.mixo_spls <- vi_model.mixo_pls
+
+
+# Package: mlr -----------------------------------------------------------------
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.WrappedModel <- function(object, ...) {  # package: mlr
+  vi_model(object$learner.model, ...)
+}
+
+
+# Package: mlr3 ----------------------------------------------------------------
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.Learner <- function(object, ...) {  # package: mlr3
+  if (is.null(object$model)) {
+    stop("No fitted model found. Did you forget to call ",
+         deparse(substitute(object)), "$train()?",
+         call. = FALSE)
+  }
+  vi_model(object$model, ...)
+}
+
 
 # Package: randomForest --------------------------------------------------------
 
@@ -918,11 +1124,11 @@ vi_model.randomForest <- function(object, ...) {
 #' @export
 vi_model.ranger <- function(object, ...) {
 
-  # # Check for dependency
-  # if (!requireNamespace("ranger", quietly = TRUE)) {
-  #   stop("Package \"ranger\" needed for this function to work. Please ",
-  #        "install it.", call. = FALSE)
-  # }
+  # Check for dependency
+  if (!requireNamespace("ranger", quietly = TRUE)) {
+    stop("Package \"ranger\" needed for this function to work. Please ",
+         "install it.", call. = FALSE)
+  }
 
   # Construct model-specific variable importance scores
   vis <- ranger::importance(object)
@@ -1302,6 +1508,29 @@ vi_model.lm <- function(object, type = c("stat", "raw"), ...) {
 }
 
 
+# tidymodels ===================================================================
+
+# Package: parsnip -------------------------------------------------------------
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.model_fit <- function(object, ...) {
+  vi_model(parsnip::extract_fit_engine(object), ...)
+}
+
+# Package: workflows -----------------------------------------------------------
+
+#' @rdname vi_model
+#'
+#' @export
+vi_model.workflow <- function(object, ...) {
+  vi_model(workflows::extract_fit_engine(object), ...)
+}
+
+#===============================================================================
+
+
 # Package: xgboost -------------------------------------------------------------
 
 #' @rdname vi_model
