@@ -27,12 +27,6 @@ expect_identical(
   target = caret::varImp(fit)$Overall
 )
 
-# Expectations for `get_training_data()`
-expect_identical(
-  current = vip:::get_training_data.default(fit),
-  target = friedman1
-)
-
 # Expectations for `get_feature_names()`
 expect_identical(
   current = vip:::get_feature_names.mvr(fit),
